==> trade-center-api-0.0.2-20160720.065955-2-sources.jar: cn/com/duiba/order/center/api/dto/queryparam/AabnormalOrderQueryDto.java <==

package cn.com.duiba.order.center.api.dto.queryparam;

import java.util.Date;

/**
 * 异常订单查询类
 */
public class AabnormalOrderQueryDto {

	private String type;
	
	private Integer facePrice;

	private String orderNum;

	private String searchType;
	
	private Date startTime;

	private Date endTime;

	private Date objectEndTime;
	
	private Date timeoutTime;
	
	private Date createTime;

	private Integer offset; // 分页偏移量

	private Integer max; // 每页个数
	
	private Integer maxId;

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Date getEndTime() {
		return endTime;
	}

	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}

	public Date getObjectEndTime() {
		return objectEndTime;
	}

	public void setObjectEndTime(Date objectEndTime) {
		this.objectEndTime = objectEndTime;
	}

	public Date getTimeoutTime() {
		return timeoutTime;
	}

	public void setTimeoutTime(Date timeoutTime) {
		this.timeoutTime = timeoutTime;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public String getSearchType() {
		return searchType;
	}

	public void setSearchType(String searchType) {
		this.searchType = searchType;
	}

	public Integer getOffset() {
		return offset;
	}

	public void setOffset(Integer offset) {
		this.offset = offset;
	}

	public Integer getMax() {
		return max;
	}
	
	public Date getStartTime() {
		return startTime;
	}

	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}

	public void setMax(Integer max) {
		this.max = max;
	}
	

	public AabnormalOrderQueryDto() {
	}

	public Integer getFacePrice() {
		return facePrice;
	}

	public void setFacePrice(Integer facePrice) {
		this.facePrice = facePrice;
	}
	
	public Integer getMaxId() {
		return maxId;
	}

	public void setMaxId(Integer maxId) {
		this.maxId = maxId;
	}

	public AabnormalOrderQueryDto(String type, Integer facePrice, String orderNum, String searchType) {
		this.type = type;
		this.facePrice = facePrice;
		this.orderNum = orderNum;
		this.searchType = searchType;
	}
}

==> trade-center-api-0.0.2-20160816.072751-35-sources.jar: cn/com/duiba/order/center/api/dto/queryparam/AabnormalOrderQueryDto.java <==

package cn.com.duiba.order.center.api.dto.queryparam;

import java.util.Date;

/**
 * 异常订单查询类
 */
public class AabnormalOrderQueryDto {

	private String type;
	
	private Integer facePrice;

	private String orderNum;

	private String searchType;
	
	private Date startTime;

	private Date endTime;

	private Date objectEndTime;
	
	private Date timeoutTime;
	
	private Date createTime;

	private Integer offset; // 分页偏移量

	private Integer max; // 每页个数
	
	private Integer maxId;

	private String lotteryType;//游戏类型

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Date getEndTime() {
		return endTime;
	}

	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}

	public Date getObjectEndTime() {
		return objectEndTime;
	}

	public void setObjectEndTime(Date objectEndTime) {
		this.objectEndTime = objectEndTime;
	}

	public Date getTimeoutTime() {
		return timeoutTime;
	}

	public void setTimeoutTime(Date timeoutTime) {
		this.timeoutTime = timeoutTime;
	}

	public Date getCreateTime() {
		return createTime;
	}

	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public String getSearchType() {
		return searchType;
	}

	public void setSearchType(String searchType) {
		this.searchType = searchType;
	}

	public Integer getOffset() {
		return offset;
	}

	public void setOffset(Integer offset) {
		this.offset = offset;
	}

	public Integer getMax() {
		return max;
	}
	
	public Date getStartTime() {
		return startTime;
	}

	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}

	public void setMax(Integer max) {
		this.max = max;
	}

	public String getLotteryType() {
		return lotteryType;
	}

	public void setLotteryType(String lotteryType) {
		this.lotteryType = lotteryType;
	}

	public AabnormalOrderQueryDto() {
	}

	public Integer getFacePrice() {
		return facePrice;
	}

	public void setFacePrice(Integer facePrice) {
		this.facePrice = facePrice;
	}
	
	public Integer getMaxId() {
		return maxId;
	}

	public void setMaxId(Integer maxId) {
		this.maxId = maxId;
	}

	public AabnormalOrderQueryDto(String type, Integer facePrice, String orderNum, String searchType) {
		this.type = type;
		this.facePrice = facePrice;
		this.orderNum = orderNum;
		this.searchType = searchType;
	}
}
